summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNikos Mavrogiannopoulos <nmav@gnutls.org>2001-11-04 16:52:44 +0000
committerNikos Mavrogiannopoulos <nmav@gnutls.org>2001-11-04 16:52:44 +0000
commitfff2766dacd0ff4903128f0e5c044f9aead4f215 (patch)
tree9b23635cc5c920c334454a58f5c41d58fba1f4b4
parent44d6c7cd4bcf0d2b485614946de74136358f860f (diff)
downloadgnutls-fff2766dacd0ff4903128f0e5c044f9aead4f215.tar.gz
changed LIST to GNUTLS_LIST
-rw-r--r--lib/gnutls.h.in12
-rw-r--r--lib/gnutls_anon_cred.c3
-rw-r--r--lib/gnutls_int.h2
-rw-r--r--lib/gnutls_priority.c20
4 files changed, 20 insertions, 17 deletions
diff --git a/lib/gnutls.h.in b/lib/gnutls.h.in
index 431197a55a..4f07442561 100644
--- a/lib/gnutls.h.in
+++ b/lib/gnutls.h.in
@@ -61,7 +61,7 @@ typedef enum GNUTLS_Version { GNUTLS_SSL3=1, GNUTLS_TLS1 } GNUTLS_Version;
*/
#define SOCKET int
-#define LIST ...
+#define GNUTLS_LIST ...
struct GNUTLS_STATE_INT;
typedef struct GNUTLS_STATE_INT* GNUTLS_STATE;
@@ -119,11 +119,11 @@ ssize_t gnutls_write(SOCKET cd, GNUTLS_STATE state, void *data, size_t sizeofdat
ssize_t gnutls_read(SOCKET cd, GNUTLS_STATE state, void *data, size_t sizeofdata);
/* functions to set priority of cipher suites */
-int gnutls_set_cipher_priority( GNUTLS_STATE state, LIST);
-int gnutls_set_mac_priority( GNUTLS_STATE state, LIST);
-int gnutls_set_compression_priority( GNUTLS_STATE state, LIST);
-int gnutls_set_kx_priority( GNUTLS_STATE state, LIST);
-int gnutls_set_protocol_priority( GNUTLS_STATE state, LIST);
+int gnutls_set_cipher_priority( GNUTLS_STATE state, GNUTLS_LIST);
+int gnutls_set_mac_priority( GNUTLS_STATE state, GNUTLS_LIST);
+int gnutls_set_compression_priority( GNUTLS_STATE state, GNUTLS_LIST);
+int gnutls_set_kx_priority( GNUTLS_STATE state, GNUTLS_LIST);
+int gnutls_set_protocol_priority( GNUTLS_STATE state, GNUTLS_LIST);
/* set our version - 0 for TLS 1.0 and 1 for SSL3 */
GNUTLS_Version gnutls_get_current_version(GNUTLS_STATE state);
diff --git a/lib/gnutls_anon_cred.c b/lib/gnutls_anon_cred.c
index 980320f6c7..ebc42f2436 100644
--- a/lib/gnutls_anon_cred.c
+++ b/lib/gnutls_anon_cred.c
@@ -58,6 +58,9 @@ int gnutls_allocate_anon_server_sc( ANON_SERVER_CREDENTIALS *sc) {
* @res: is an &ANON_SERVER_CREDENTIALS structure.
* @dh_bits: is the number of bits in DH key exchange
*
+ * Used to set the number of bits to use in an anonymous Diffie-Hellman,
+ * key exchange.
+ *
**/
int gnutls_set_anon_server_cred( ANON_SERVER_CREDENTIALS res, int dh_bits) {
diff --git a/lib/gnutls_int.h b/lib/gnutls_int.h
index baa219aa24..f24784d5bf 100644
--- a/lib/gnutls_int.h
+++ b/lib/gnutls_int.h
@@ -41,7 +41,7 @@
*/
#define SOCKET int
-#define LIST ...
+#define GNUTLS_LIST ...
#define MAX32 4294967295
#define MAX24 16777215
diff --git a/lib/gnutls_priority.c b/lib/gnutls_priority.c
index 94af37847b..747dfbf844 100644
--- a/lib/gnutls_priority.c
+++ b/lib/gnutls_priority.c
@@ -27,7 +27,7 @@
/**
* gnutls_set_cipher_priority - Sets the priority on the ciphers supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
* @LIST: is a 0 terminated list of BulkCipherAlgorithm elements.
*
* Sets the priority on the ciphers supported by gnutls.
* Priority is higher for ciphers specified before others.
@@ -36,7 +36,7 @@
* not use the algorithm's priority except for disabling
* algorithms that were not specified.
**/
-int gnutls_set_cipher_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_cipher_priority( GNUTLS_STATE state, GNUTLS_LIST) {
va_list ap;
int i,num=0;
@@ -70,7 +70,7 @@ int gnutls_set_cipher_priority( GNUTLS_STATE state, LIST) {
/**
* gnutls_set_kx_priority - Sets the priority on the key exchange algorithms supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
* @LIST: is a 0 terminated list of KXAlgorithm elements.
*
* Sets the priority on the key exchange algorithms supported by gnutls.
* Priority is higher for algorithms specified before others.
@@ -79,7 +79,7 @@ int gnutls_set_cipher_priority( GNUTLS_STATE state, LIST) {
* not use the algorithm's priority except for disabling
* algorithms that were not specified.
**/
-int gnutls_set_kx_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_kx_priority( GNUTLS_STATE state, GNUTLS_LIST) {
va_list ap;
va_list _ap;
@@ -110,7 +110,7 @@ int gnutls_set_kx_priority( GNUTLS_STATE state, LIST) {
/**
* gnutls_set_mac_priority - Sets the priority on the mac algorithms supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
* @LIST: is a 0 terminated list of MACAlgorithm elements.
*
* Sets the priority on the mac algorithms supported by gnutls.
* Priority is higher for algorithms specified before others.
@@ -119,7 +119,7 @@ int gnutls_set_kx_priority( GNUTLS_STATE state, LIST) {
* not use the algorithm's priority except for disabling
* algorithms that were not specified.
**/
-int gnutls_set_mac_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_mac_priority( GNUTLS_STATE state, GNUTLS_LIST) {
va_list ap;
int i, num=0;
@@ -150,7 +150,7 @@ int gnutls_set_mac_priority( GNUTLS_STATE state, LIST) {
/**
* gnutls_set_compression_priority - Sets the priority on the compression algorithms supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
* @LIST: is a 0 terminated list of CompressionMethod elements.
*
* Sets the priority on the compression algorithms supported by gnutls.
* Priority is higher for algorithms specified before others.
@@ -159,7 +159,7 @@ int gnutls_set_mac_priority( GNUTLS_STATE state, LIST) {
* not use the algorithm's priority except for disabling
* algorithms that were not specified.
**/
-int gnutls_set_compression_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_compression_priority( GNUTLS_STATE state, GNUTLS_LIST) {
va_list ap;
int i,num=0;
@@ -189,7 +189,7 @@ int gnutls_set_compression_priority( GNUTLS_STATE state, LIST) {
/**
* gnutls_set_protocol_priority - Sets the priority on the protocol versions supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
* @LIST: is a 0 terminated list of GNUTLS_Version elements.
*
* Sets the priority on the protocol versions supported by gnutls.
* Priority is higher for protocols specified before others.
@@ -198,7 +198,7 @@ int gnutls_set_compression_priority( GNUTLS_STATE state, LIST) {
* not use the protocols's priority except for disabling
* protocols that were not specified.
**/
-int gnutls_set_protocol_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_protocol_priority( GNUTLS_STATE state, GNUTLS_LIST) {
va_list ap;
int i,num=0;
@@ -27,7 +27,7 @@
* gnutls_set_cipher_priority - Sets the priority on the ciphers supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
- * @LIST: is a 0 terminated list of BulkCipherAlgorithm elements.
+ * @GNUTLS_LIST: is a 0 terminated list of BulkCipherAlgorithm elements.
*
* Sets the priority on the ciphers supported by gnutls.
@@ -70,7 +70,7 @@ int gnutls_set_cipher_priority( GNUTLS_STATE state, LIST) {
* gnutls_set_kx_priority - Sets the priority on the key exchange algorithms supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
- * @LIST: is a 0 terminated list of KXAlgorithm elements.
+ * @GNUTLS_LIST: is a 0 terminated list of KXAlgorithm elements.
*
* Sets the priority on the key exchange algorithms supported by gnutls.
@@ -110,7 +110,7 @@ int gnutls_set_kx_priority( GNUTLS_STATE state, LIST) {
* gnutls_set_mac_priority - Sets the priority on the mac algorithms supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
- * @LIST: is a 0 terminated list of MACAlgorithm elements.
+ * @GNUTLS_LIST: is a 0 terminated list of MACAlgorithm elements.
*
* Sets the priority on the mac algorithms supported by gnutls.
@@ -150,7 +150,7 @@ int gnutls_set_mac_priority( GNUTLS_STATE state, LIST) {
* gnutls_set_compression_priority - Sets the priority on the compression algorithms supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
- * @LIST: is a 0 terminated list of CompressionMethod elements.
+ * @GNUTLS_LIST: is a 0 terminated list of CompressionMethod elements.
*
* Sets the priority on the compression algorithms supported by gnutls.
@@ -189,7 +189,7 @@ int gnutls_set_compression_priority( GNUTLS_STATE state, LIST) {
* gnutls_set_protocol_priority - Sets the priority on the protocol versions supported by gnutls.
* @state: is a &GNUTLS_STATE structure.
- * @LIST: is a 0 terminated list of GNUTLS_Version elements.
+ * @GNUTLS_LIST: is a 0 terminated list of GNUTLS_Version elements.
*
* Sets the priority on the protocol versions supported by gnutls.